.. Xœuvre documentation master file, created by
   sphinx-quickstart on Tue May  7 07:58:55 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

==================================
Welcome to ``xœuf`` documentation!
==================================

.. todo:: Place a one-paragraph summary of the purpose of this package.


Modules
=======

.. toctree::
   :glob:
   :maxdepth: 1

   xoeuf/*
   xoeuf/**


Other documents
===============

.. toctree::
   :glob:
   :maxdepth: 1

   history
   license



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
